.. _mpris-clients:

*************
MPRIS clients
*************

`MPRIS <https://specifications.freedesktop.org/mpris-spec/latest/>`_ is short
for Media Player Remote Interfacing Specification. It is a spec that describes
a standard D-Bus interface for making media players available to other
applications on the same system.

See the `Mopidy-MPRIS documentation <https://github.com/mopidy/mopidy-mpris>`_
for a survey of some MPRIS clients.
